@@ -112,6 +112,33 @@ e_book_backend_sqlitedb_error_quark (void)
 	return quark;
 }
 
+static void
+e_book_backend_sqlitedb_dispose (GObject *object)
+{
+        EBookBackendSqliteDBPrivate *priv;
+
+	priv = E_BOOK_BACKEND_SQLITEDB (object)->priv;
+
+        g_static_mutex_lock (&dbcon_lock);
+	if (db_connections != NULL) {
+	        if (priv->hash_key != NULL) {
+		        g_hash_table_remove (db_connections, priv->hash_key);
+
+		        if (g_hash_table_size (db_connections) == 0) {
+			        g_hash_table_destroy (db_connections);
+			        db_connections = NULL;
+		        }
+
+		        g_free (priv->hash_key);
+		        priv->hash_key = NULL;
+		}
+	}
+	g_static_mutex_unlock (&dbcon_lock);
+	
+	/* Chain up to parent's dispose() method. */
+	G_OBJECT_CLASS (e_book_backend_sqlitedb_parent_class)->dispose (object);
+}
+
 static void
 e_book_backend_sqlitedb_finalize (GObject *object)
 {
@@ -127,20 +154,6 @@ e_book_backend_sqlitedb_finalize (GObject *object)
 	g_free (priv->path);
 	priv->path = NULL;
 
-	g_static_mutex_lock (&dbcon_lock);
-	if (db_connections != NULL) {
-		g_hash_table_remove (db_connections, priv->hash_key);
-
-		if (g_hash_table_size (db_connections) == 0) {
-			g_hash_table_destroy (db_connections);
-			db_connections = NULL;
-		}
-
-		g_free (priv->hash_key);
-		priv->hash_key = NULL;
-	}
-	g_static_mutex_unlock (&dbcon_lock);
-
 	g_free (priv);
 	priv = NULL;
 
@@ -156,6 +169,7 @@ e_book_backend_sqlitedb_class_init (EBookBackendSqliteDBClass *class)
 	g_type_class_add_private (class, sizeof (EBookBackendSqliteDBPrivate));
 
 	object_class = G_OBJECT_CLASS (class);
+	object_class->dispose = e_book_backend_sqlitedb_dispose;
 	object_class->finalize = e_book_backend_sqlitedb_finalize;
 }
 
@@ -411,7 +425,7 @@ create_contacts_table (EBookBackendSqliteDB *ebsdb,
 		else if (summary_fields[i].fundamental_type == G_TYPE_BOOLEAN)
 			g_string_append (string, "INTEGER, ");
 		else
-			g_assert_not_reached ();
+			g_warn_if_reached ();
 	}
 	g_string_append (string, "vcard TEXT, bdata TEXT)");
 
@@ -540,13 +554,20 @@ e_book_backend_sqlitedb_new (const gchar *path,
 	ebsdb->priv->path = g_strdup (path);
 	ebsdb->priv->store_vcard = store_vcard;
 	if (g_mkdir_with_parents (path, 0777) < 0) {
+		g_static_mutex_unlock (&dbcon_lock);
 		g_set_error (error, E_BOOK_SDB_ERROR,
 				0, "Can not make parent directory: errno %d", errno);
 		return NULL;
 	}
 	filename = g_build_filename (path, DB_FILENAME, NULL);
 
-	book_backend_sqlitedb_load (ebsdb, filename, &err);
+	if (!book_backend_sqlitedb_load (ebsdb, filename, &err)) {
+        	g_static_mutex_unlock (&dbcon_lock);
+        	g_propagate_error (error, err);
+        	g_object_unref (ebsdb);
+        	g_free (filename);
+	        return NULL;
+	}
 	g_free (filename);
 
 	if (db_connections == NULL)
@@ -605,7 +626,7 @@ insert_stmt_from_contact (EContact *contact,
 			g_string_append_printf (string, "%d", val ? 1 : 0);
 
 		} else
-			g_assert_not_reached ();
+			g_warn_if_reached ();
 	}
 
 	vcard_str = store_vcard ? e_vcard_to_string (E_VCARD (contact), EVC_FORMAT_VCARD_30) : NULL;
@@ -748,7 +769,7 @@ e_book_backend_sqlitedb_remove_contacts (EBookBackendSqliteDB *ebsdb,
 	sqlite3_free (tmp);
 
 	for (l = uids; l != NULL; l = g_slist_next (l)) {
-		gchar *uid = (gchar *) uids->data;
+		gchar *uid = (gchar *) l->data;
 
 		tmp = sqlite3_mprintf ("%Q", uid);
 		g_string_append_printf (str, " %s ,", tmp);
@@ -1051,13 +1072,14 @@ func_check (struct _ESExp *f,
 	if (argc == 2
 	    && argv[0]->type == ESEXP_RES_STRING
 	    && argv[1]->type == ESEXP_RES_STRING) {
-
-		gchar *query_name = argv[0]->value.string;
+		const gchar *query_name = argv[0]->value.string;
+		const gchar *query_value = argv[1]->value.string;
 		gint   i;
 
 		/* Special case, when testing the special symbolic 'any field' we can
 		 * consider it a summary query (it's similar to a 'no query'). */
-		if (!strcmp ("x-evolution-any-field", query_name))
+		if (g_strcmp0 (query_name, "x-evolution-any-field") == 0 &&
+		    g_strcmp0 (query_value, "") == 0)
 			truth = TRUE;
 
 		for (i = 0; truth == FALSE && i < G_N_ELEMENTS (summary_fields); i++) {
@@ -1136,6 +1158,38 @@ e_book_backend_sqlitedb_is_summary_query (const gchar *query)
 	return retval;
 }
 
+static ESExpResult *
+func_and (ESExp *f, gint argc, struct _ESExpTerm **argv, gpointer data)
+{
+	ESExpResult *r, *r1;
+	GString *string;
+	gint i;
+
+	string = g_string_new("( ");
+	for (i = 0; i < argc; i++) {
+		r1 = e_sexp_term_eval (f, argv[i]);
+
+		if (r1->type != ESEXP_RES_STRING) {
+			e_sexp_result_free (f, r1);
+			continue;
+		}
+		if (r1->value.string && *r1->value.string)
+			g_string_append_printf(string, "%s%s", r1->value.string, ((argc>1) && (i != argc-1)) ?  " AND ":"");
+		e_sexp_result_free (f, r1);
+	}
+	g_string_append(string, " )");
+	r = e_sexp_result_new (f, ESEXP_RES_STRING);
+
+	if (strlen (string->str) == 4) {
+		r->value.string = g_strdup("");
+		g_string_free (string, TRUE);
+	} else {
+		r->value.string = g_string_free (string, FALSE);
+	}
+
+	return r;
+}
+
 static ESExpResult *
 func_or (ESExp *f,
          gint argc,
@@ -1154,14 +1208,20 @@ func_or (ESExp *f,
 			e_sexp_result_free (f, r1);
 			continue;
 		}
-		g_string_append_printf(string, "%s%s", r1->value.string, ((argc>1) && (i != argc-1)) ?  " OR ":"");
+		if (r1->value.string && *r1->value.string)
+			g_string_append_printf(string, "%s%s", r1->value.string, ((argc>1) && (i != argc-1)) ?  " OR ":"");
 		e_sexp_result_free (f, r1);
 	}
 	g_string_append(string, " )");
 
 	r = e_sexp_result_new (f, ESEXP_RES_STRING);
-	r->value.string = string->str;
-	g_string_free (string, FALSE);
+	if (strlen (string->str) == 4) {
+		r->value.string = g_strdup("");
+		g_string_free (string, TRUE);
+	} else {
+		r->value.string = g_string_free (string, FALSE);
+	}
+
 	return r;
 }
 
@@ -1282,6 +1342,7 @@ static struct {
 	ESExpFunc *func;
 	guint immediate :1;
 } symbols[] = {
+	{ "and", (ESExpFunc *) func_and, 1},
 	{ "or", (ESExpFunc *) func_or, 1},
 
 	{ "contains", func_contains, 0 },
@@ -1316,12 +1377,16 @@ sexp_to_sql_query (const gchar *query)
 	if (!r)
 		return NULL;
 	if (r->type == ESEXP_RES_STRING) {
-		res = g_strdup (r->value.string);
+		if (r->value.string && *r->value.string)
+			res = g_strdup (r->value.string);
+		else
+			res = NULL;
 	} else
-		g_assert (0);
+		g_warn_if_reached ();
 
 	e_sexp_result_free (sexp, r);
 	e_sexp_unref (sexp);
+
 	return res;
 }
 
@@ -1392,7 +1457,7 @@ store_data_to_vcard (gpointer ref,
 					gboolean val = cols[i] ? strtoul (cols[i], NULL, 10) != 0 : FALSE;
 					e_contact_set (contact, summary_fields[j].field, GINT_TO_POINTER (val ? TRUE : FALSE));
 				} else
-					g_assert_not_reached ();
+					g_warn_if_reached ();
 
 				if (summary_fields[j].field == E_CONTACT_UID)
 					search_data->uid = g_strdup (cols[i]);
