@@ -16,7 +16,8 @@
 #include "e-data-book.h"
 #include "e-book-backend.h"
 
-#define EDB_OPENING_ERROR e_data_book_create_error (E_DATA_BOOK_STATUS_BUSY, _("Cannot process, book backend is opening"))
+#define EDB_OPENING_ERROR	e_data_book_create_error (E_DATA_BOOK_STATUS_BUSY, _("Cannot process, book backend is opening"))
+#define EDB_NOT_OPENED_ERROR	e_data_book_create_error (E_DATA_BOOK_STATUS_NOT_OPENED, NULL)
 
 struct _EBookBackendPrivate {
 	GMutex *clients_mutex;
@@ -70,7 +71,11 @@ book_backend_set_default_cache_dir (EBookBackend *backend)
 }
 
 static void
-book_backend_get_backend_property (EBookBackend *backend, EDataBook *book, guint32 opid, GCancellable *cancellable, const gchar *prop_name)
+book_backend_get_backend_property (EBookBackend *backend,
+                                   EDataBook *book,
+                                   guint32 opid,
+                                   GCancellable *cancellable,
+                                   const gchar *prop_name)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
@@ -93,7 +98,12 @@ book_backend_get_backend_property (EBookBackend *backend, EDataBook *book, guint
 }
 
 static void
-book_backend_set_backend_property (EBookBackend *backend, EDataBook *book, guint32 opid, GCancellable *cancellable, const gchar *prop_name, const gchar *prop_value)
+book_backend_set_backend_property (EBookBackend *backend,
+                                   EDataBook *book,
+                                   guint32 opid,
+                                   GCancellable *cancellable,
+                                   const gchar *prop_name,
+                                   const gchar *prop_value)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
@@ -176,6 +186,22 @@ book_backend_finalize (GObject *object)
 	G_OBJECT_CLASS (e_book_backend_parent_class)->finalize (object);
 }
 
+static gboolean
+view_notify_update (EDataBookView *view,
+                    gpointer contact)
+{
+	e_data_book_view_notify_update (view, contact);
+
+	return TRUE;
+}
+
+static void
+book_backend_notify_update (EBookBackend *backend,
+                            const EContact *contact)
+{
+	e_book_backend_foreach_view (backend, view_notify_update, (gpointer) contact);
+}
+
 static void
 e_book_backend_class_init (EBookBackendClass *klass)
 {
@@ -191,6 +217,7 @@ e_book_backend_class_init (EBookBackendClass *klass)
 
 	klass->get_backend_property = book_backend_get_backend_property;
 	klass->set_backend_property = book_backend_set_backend_property;
+	klass->notify_update        = book_backend_notify_update;
 
 	g_object_class_install_property (
 		object_class,
@@ -342,10 +369,10 @@ e_book_backend_get_source (EBookBackend *backend)
  **/
 void
 e_book_backend_open (EBookBackend *backend,
-		     EDataBook    *book,
-		     guint32       opid,
-		     GCancellable *cancellable,
-		     gboolean      only_if_exists)
+                     EDataBook *book,
+                     guint32 opid,
+                     GCancellable *cancellable,
+                     gboolean only_if_exists)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK (book));
@@ -396,9 +423,9 @@ e_book_backend_open (EBookBackend *backend,
  **/
 void
 e_book_backend_remove (EBookBackend *backend,
-		       EDataBook    *book,
-		       guint32       opid,
-		       GCancellable *cancellable)
+                       EDataBook *book,
+                       guint32 opid,
+                       GCancellable *cancellable)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK (book));
@@ -427,7 +454,10 @@ e_book_backend_remove (EBookBackend *backend,
  * Since: 3.2
  **/
 void
-e_book_backend_refresh (EBookBackend *backend, EDataBook *book, guint32 opid, GCancellable *cancellable)
+e_book_backend_refresh (EBookBackend *backend,
+                        EDataBook *book,
+                        guint32 opid,
+                        GCancellable *cancellable)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
@@ -436,6 +466,8 @@ e_book_backend_refresh (EBookBackend *backend, EDataBook *book, guint32 opid, GC
 		e_data_book_respond_refresh (book, opid, EDB_OPENING_ERROR);
 	else if (!E_BOOK_BACKEND_GET_CLASS (backend)->refresh)
 		e_data_book_respond_refresh (book, opid, e_data_book_create_error (E_DATA_BOOK_STATUS_NOT_SUPPORTED, NULL));
+	else if (!e_book_backend_is_opened (backend))
+		e_data_book_respond_refresh (book, opid, EDB_NOT_OPENED_ERROR);
 	else
 		(* E_BOOK_BACKEND_GET_CLASS (backend)->refresh) (backend, book, opid, cancellable);
 }
@@ -454,10 +486,10 @@ e_book_backend_refresh (EBookBackend *backend, EDataBook *book, guint32 opid, GC
  **/
 void
 e_book_backend_create_contact (EBookBackend *backend,
-			       EDataBook    *book,
-			       guint32       opid,
-			       GCancellable *cancellable,
-			       const gchar   *vcard)
+                               EDataBook *book,
+                               guint32 opid,
+                               GCancellable *cancellable,
+                               const gchar *vcard)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK (book));
@@ -466,6 +498,8 @@ e_book_backend_create_contact (EBookBackend *backend,
 
 	if (e_book_backend_is_opening (backend))
 		e_data_book_respond_create (book, opid, EDB_OPENING_ERROR, NULL);
+	else if (!e_book_backend_is_opened (backend))
+		e_data_book_respond_create (book, opid, EDB_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_BOOK_BACKEND_GET_CLASS (backend)->create_contact) (backend, book, opid, cancellable, vcard);
 }
@@ -484,10 +518,10 @@ e_book_backend_create_contact (EBookBackend *backend,
  **/
 void
 e_book_backend_remove_contacts (EBookBackend *backend,
-				EDataBook    *book,
-				guint32       opid,
-				GCancellable *cancellable,
-				const GSList *id_list)
+                                EDataBook *book,
+                                guint32 opid,
+                                GCancellable *cancellable,
+                                const GSList *id_list)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK (book));
@@ -496,6 +530,8 @@ e_book_backend_remove_contacts (EBookBackend *backend,
 
 	if (e_book_backend_is_opening (backend))
 		e_data_book_respond_remove_contacts (book, opid, EDB_OPENING_ERROR, NULL);
+	else if (!e_book_backend_is_opened (backend))
+		e_data_book_respond_remove_contacts (book, opid, EDB_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_BOOK_BACKEND_GET_CLASS (backend)->remove_contacts) (backend, book, opid, cancellable, id_list);
 }
@@ -514,10 +550,10 @@ e_book_backend_remove_contacts (EBookBackend *backend,
  **/
 void
 e_book_backend_modify_contact (EBookBackend *backend,
-			       EDataBook    *book,
-			       guint32       opid,
-			       GCancellable *cancellable,
-			       const gchar   *vcard)
+                               EDataBook *book,
+                               guint32 opid,
+                               GCancellable *cancellable,
+                               const gchar *vcard)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK (book));
@@ -526,6 +562,8 @@ e_book_backend_modify_contact (EBookBackend *backend,
 
 	if (e_book_backend_is_opening (backend))
 		e_data_book_respond_modify (book, opid, EDB_OPENING_ERROR, NULL);
+	else if (!e_book_backend_is_opened (backend))
+		e_data_book_respond_modify (book, opid, EDB_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_BOOK_BACKEND_GET_CLASS (backend)->modify_contact) (backend, book, opid, cancellable, vcard);
 }
@@ -544,10 +582,10 @@ e_book_backend_modify_contact (EBookBackend *backend,
  **/
 void
 e_book_backend_get_contact (EBookBackend *backend,
-			    EDataBook    *book,
-			    guint32       opid,
-			    GCancellable *cancellable,
-			    const gchar   *id)
+                            EDataBook *book,
+                            guint32 opid,
+                            GCancellable *cancellable,
+                            const gchar *id)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK (book));
@@ -556,6 +594,8 @@ e_book_backend_get_contact (EBookBackend *backend,
 
 	if (e_book_backend_is_opening (backend))
 		e_data_book_respond_get_contact (book, opid, EDB_OPENING_ERROR, NULL);
+	else if (!e_book_backend_is_opened (backend))
+		e_data_book_respond_get_contact (book, opid, EDB_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_BOOK_BACKEND_GET_CLASS (backend)->get_contact) (backend, book, opid, cancellable, id);
 }
@@ -574,10 +614,10 @@ e_book_backend_get_contact (EBookBackend *backend,
  **/
 void
 e_book_backend_get_contact_list (EBookBackend *backend,
-				 EDataBook    *book,
-				 guint32       opid,
-				 GCancellable *cancellable,
-				 const gchar   *query)
+                                 EDataBook *book,
+                                 guint32 opid,
+                                 GCancellable *cancellable,
+                                 const gchar *query)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK (book));
@@ -586,6 +626,8 @@ e_book_backend_get_contact_list (EBookBackend *backend,
 
 	if (e_book_backend_is_opening (backend))
 		e_data_book_respond_get_contact_list (book, opid, EDB_OPENING_ERROR, NULL);
+	else if (!e_book_backend_is_opened (backend))
+		e_data_book_respond_get_contact_list (book, opid, EDB_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_BOOK_BACKEND_GET_CLASS (backend)->get_contact_list) (backend, book, opid, cancellable, query);
 }
@@ -606,10 +648,10 @@ e_book_backend_get_contact_list (EBookBackend *backend,
  **/
 void
 e_book_backend_get_contact_list_uids (EBookBackend *backend,
-				      EDataBook    *book,
-				      guint32       opid,
-				      GCancellable *cancellable,
-				      const gchar   *query)
+                                      EDataBook *book,
+                                      guint32 opid,
+                                      GCancellable *cancellable,
+                                      const gchar *query)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK (book));
@@ -618,6 +660,8 @@ e_book_backend_get_contact_list_uids (EBookBackend *backend,
 
 	if (e_book_backend_is_opening (backend))
 		e_data_book_respond_get_contact_list_uids (book, opid, EDB_OPENING_ERROR, NULL);
+	else if (!e_book_backend_is_opened (backend))
+		e_data_book_respond_get_contact_list_uids (book, opid, EDB_NOT_OPENED_ERROR, NULL);
 	else
 		(* E_BOOK_BACKEND_GET_CLASS (backend)->get_contact_list_uids) (backend, book, opid, cancellable, query);
 }
@@ -631,8 +675,8 @@ e_book_backend_get_contact_list_uids (EBookBackend *backend,
  * signals for matching contacts.
  **/
 void
-e_book_backend_start_book_view (EBookBackend  *backend,
-				EDataBookView *book_view)
+e_book_backend_start_book_view (EBookBackend *backend,
+                                EDataBookView *book_view)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK_VIEW (book_view));
@@ -650,8 +694,8 @@ e_book_backend_start_book_view (EBookBackend  *backend,
  * no more signals.
  **/
 void
-e_book_backend_stop_book_view (EBookBackend  *backend,
-			       EDataBookView *book_view)
+e_book_backend_stop_book_view (EBookBackend *backend,
+                               EDataBookView *book_view)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK_VIEW (book_view));
@@ -678,8 +722,8 @@ e_book_backend_stop_book_view (EBookBackend  *backend,
  **/
 void
 e_book_backend_authenticate_user (EBookBackend *backend,
-				  GCancellable *cancellable,
-				  ECredentials *credentials)
+                                  GCancellable *cancellable,
+                                  ECredentials *credentials)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (credentials != NULL);
@@ -706,7 +750,7 @@ last_client_gone (EBookBackend *backend)
  **/
 void
 e_book_backend_add_book_view (EBookBackend *backend,
-			      EDataBookView *view)
+                              EDataBookView *view)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 
@@ -726,7 +770,7 @@ e_book_backend_add_book_view (EBookBackend *backend,
  **/
 void
 e_book_backend_remove_book_view (EBookBackend *backend,
-				 EDataBookView *view)
+                                 EDataBookView *view)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 
@@ -747,8 +791,8 @@ e_book_backend_remove_book_view (EBookBackend *backend,
  * Returns: TRUE on success, FALSE on failure to add the client.
  */
 gboolean
-e_book_backend_add_client (EBookBackend      *backend,
-			   EDataBook         *book)
+e_book_backend_add_client (EBookBackend *backend,
+                           EDataBook *book)
 {
 	g_return_val_if_fail (E_IS_BOOK_BACKEND (backend), FALSE);
 	g_return_val_if_fail (E_IS_DATA_BOOK (book), FALSE);
@@ -769,14 +813,14 @@ e_book_backend_add_client (EBookBackend      *backend,
  **/
 void
 e_book_backend_remove_client (EBookBackend *backend,
-			      EDataBook    *book)
+                              EDataBook *book)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK (book));
 
 	/* up our backend's refcount here so that last_client_gone
-	   doesn't end up unreffing us (while we're holding the
-	   lock) */
+	 * doesn't end up unreffing us (while we're holding the
+	 * lock) */
 	g_object_ref (backend);
 
 	/* Disconnect */
@@ -786,8 +830,10 @@ e_book_backend_remove_client (EBookBackend *backend,
 	/* When all clients go away, notify the parent factory about it so that
 	 * it may decide whether to kill the backend or not.
 	 */
-	if (!backend->priv->clients)
+	if (!backend->priv->clients) {
+		backend->priv->opening = FALSE;
 		last_client_gone (backend);
+	}
 
 	g_mutex_unlock (backend->priv->clients_mutex);
 
@@ -802,9 +848,14 @@ e_book_backend_remove_client (EBookBackend *backend,
  *
  * Calls @callback for each known book view of this @backend.
  * @callback returns %FALSE to stop further processing.
+ *
+ * Since: 3.2
  **/
 void
-e_book_backend_foreach_view (EBookBackend *backend, gboolean (* callback) (EDataBookView *view, gpointer user_data), gpointer user_data)
+e_book_backend_foreach_view (EBookBackend *backend,
+                             gboolean (*callback) (EDataBookView *view,
+                                                   gpointer user_data),
+                             gpointer user_data)
 {
 	const GSList *views;
 	EDataBookView *view;
@@ -844,7 +895,11 @@ e_book_backend_foreach_view (EBookBackend *backend, gboolean (* callback) (EData
  * Since: 3.2
  **/
 void
-e_book_backend_get_backend_property (EBookBackend *backend, EDataBook *book, guint32 opid, GCancellable *cancellable, const gchar *prop_name)
+e_book_backend_get_backend_property (EBookBackend *backend,
+                                     EDataBook *book,
+                                     guint32 opid,
+                                     GCancellable *cancellable,
+                                     const gchar *prop_name)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_BOOK_BACKEND_GET_CLASS (backend)->get_backend_property);
@@ -870,7 +925,12 @@ e_book_backend_get_backend_property (EBookBackend *backend, EDataBook *book, gui
  * Since: 3.2
  **/
 void
-e_book_backend_set_backend_property (EBookBackend *backend, EDataBook *book, guint32 opid, GCancellable *cancellable, const gchar *prop_name, const gchar *prop_value)
+e_book_backend_set_backend_property (EBookBackend *backend,
+                                     EDataBook *book,
+                                     guint32 opid,
+                                     GCancellable *cancellable,
+                                     const gchar *prop_name,
+                                     const gchar *prop_value)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
@@ -888,6 +948,8 @@ e_book_backend_set_backend_property (EBookBackend *backend, EDataBook *book, gui
  * Checks if @backend's storage is online.
  *
  * Returns: %TRUE if online, %FALSE otherwise.
+ *
+ * Since: 3.2
  **/
 gboolean
 e_book_backend_is_online (EBookBackend *backend)
@@ -907,6 +969,8 @@ e_book_backend_is_online (EBookBackend *backend)
  * within call of e_book_backend_notify_opened().
  *
  * Returns: %TRUE if fully opened, %FALSE otherwise.
+ *
+ * Since: 3.2
  **/
 gboolean
 e_book_backend_is_opened (EBookBackend *backend)
@@ -928,6 +992,8 @@ e_book_backend_is_opened (EBookBackend *backend)
  * it is being opening.
  *
  * Returns: %TRUE if opening phase is in the effect, %FALSE otherwise.
+ *
+ * Since: 3.2
  **/
 gboolean
 e_book_backend_is_opening (EBookBackend *backend)
@@ -944,6 +1010,8 @@ e_book_backend_is_opening (EBookBackend *backend)
  * Checks if we can write to @backend.
  *
  * Returns: %TRUE if writeable, %FALSE if not.
+ *
+ * Since: 3.2
  **/
 gboolean
 e_book_backend_is_readonly (EBookBackend *backend)
@@ -978,7 +1046,8 @@ e_book_backend_is_removed (EBookBackend *backend)
  * Meant to be used by backend implementations.
  **/
 void
-e_book_backend_set_is_removed (EBookBackend *backend, gboolean is_removed)
+e_book_backend_set_is_removed (EBookBackend *backend,
+                               gboolean is_removed)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 
@@ -993,7 +1062,8 @@ e_book_backend_set_is_removed (EBookBackend *backend, gboolean is_removed)
  * Sets @backend's online/offline mode to @is_online.
  **/
 void
-e_book_backend_set_online (EBookBackend *backend, gboolean is_online)
+e_book_backend_set_online (EBookBackend *backend,
+                           gboolean is_online)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_BOOK_BACKEND_GET_CLASS (backend)->set_online);
@@ -1024,16 +1094,6 @@ e_book_backend_sync (EBookBackend *backend)
 	g_object_unref (backend);
 }
 
-
-
-static gboolean
-view_notify_update (EDataBookView *view, gpointer contact)
-{
-	e_data_book_view_notify_update (view, contact);
-
-	return TRUE;
-}
-
 /**
  * e_book_backend_notify_update:
  * @backend: an #EBookBackend
@@ -1047,13 +1107,15 @@ view_notify_update (EDataBookView *view, gpointer contact)
  * contacts are created or modified by another (non-PAS-using) client.
  **/
 void
-e_book_backend_notify_update (EBookBackend *backend, const EContact *contact)
+e_book_backend_notify_update (EBookBackend *backend,
+                              const EContact *contact)
 {
-	e_book_backend_foreach_view (backend, view_notify_update, (gpointer) contact);
+	E_BOOK_BACKEND_GET_CLASS (backend)->notify_update (backend, contact);
 }
 
 static gboolean
-view_notify_remove (EDataBookView *view, gpointer id)
+view_notify_remove (EDataBookView *view,
+                    gpointer id)
 {
 	e_data_book_view_notify_remove (view, id);
 
@@ -1073,13 +1135,15 @@ view_notify_remove (EDataBookView *view, gpointer id)
  * another (non-PAS-using) client.
  **/
 void
-e_book_backend_notify_remove (EBookBackend *backend, const gchar *id)
+e_book_backend_notify_remove (EBookBackend *backend,
+                              const gchar *id)
 {
 	e_book_backend_foreach_view (backend, view_notify_remove, (gpointer) id);
 }
 
 static gboolean
-view_notify_complete (EDataBookView *view, gpointer unused)
+view_notify_complete (EDataBookView *view,
+                      gpointer unused)
 {
 	e_data_book_view_notify_complete (view, NULL /* SUCCESS */);
 
@@ -1109,9 +1173,12 @@ e_book_backend_notify_complete (EBookBackend *backend)
  * Notifies each backend listener about an error. This is meant to be used
  * for cases where is no GError return possibility, to notify user about
  * an issue.
+ *
+ * Since: 3.2
  **/
 void
-e_book_backend_notify_error (EBookBackend *backend, const gchar *message)
+e_book_backend_notify_error (EBookBackend *backend,
+                             const gchar *message)
 {
 	EBookBackendPrivate *priv;
 	GSList *clients;
@@ -1132,9 +1199,12 @@ e_book_backend_notify_error (EBookBackend *backend, const gchar *message)
  * @is_readonly: flag indicating readonly status
  *
  * Notifies all backend's clients about the current readonly state.
+ *
+ * Since: 3.2
  **/
 void
-e_book_backend_notify_readonly (EBookBackend *backend, gboolean is_readonly)
+e_book_backend_notify_readonly (EBookBackend *backend,
+                                gboolean is_readonly)
 {
 	EBookBackendPrivate *priv;
 	GSList *clients;
@@ -1157,9 +1227,12 @@ e_book_backend_notify_readonly (EBookBackend *backend, gboolean is_readonly)
  *
  * Notifies clients of @backend's connection status indicated by @is_online.
  * Meant to be used by backend implementations.
+ *
+ * Since: 3.2
  **/
 void
-e_book_backend_notify_online (EBookBackend *backend, gboolean is_online)
+e_book_backend_notify_online (EBookBackend *backend,
+                              gboolean is_online)
 {
 	EBookBackendPrivate *priv;
 	GSList *clients;
@@ -1197,7 +1270,9 @@ e_book_backend_notify_online (EBookBackend *backend, gboolean is_online)
  * Meant to be used by backend implementations.
  **/
 void
-e_book_backend_notify_auth_required (EBookBackend *backend, gboolean is_self, const ECredentials *credentials)
+e_book_backend_notify_auth_required (EBookBackend *backend,
+                                     gboolean is_self,
+                                     const ECredentials *credentials)
 {
 	EBookBackendPrivate *priv;
 	GSList *clients;
@@ -1232,9 +1307,12 @@ e_book_backend_notify_auth_required (EBookBackend *backend, gboolean is_self, co
  * Note: The @error is freed automatically if not %NULL.
  *
  * Meant to be used by backend implementations.
+ *
+ * Since: 3.2
  **/
 void
-e_book_backend_notify_opened (EBookBackend *backend, GError *error)
+e_book_backend_notify_opened (EBookBackend *backend,
+                              GError *error)
 {
 	EBookBackendPrivate *priv;
 	GSList *clients;
@@ -1254,6 +1332,40 @@ e_book_backend_notify_opened (EBookBackend *backend, GError *error)
 		g_error_free (error);
 }
 
+/**
+ * e_book_backend_notify_property_changed:
+ * @backend: an #EBookBackend
+ * @prop_name: property name, which changed
+ * @prop_value: new property value
+ *
+ * Notifies clients about property value change.
+ *
+ * Since: 3.2
+ **/
+void
+e_book_backend_notify_property_changed (EBookBackend *backend,
+                                        const gchar *prop_name,
+                                        const gchar *prop_value)
+{
+	EBookBackendPrivate *priv;
+	GSList *clients;
+
+	g_return_if_fail (backend != NULL);
+	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
+	g_return_if_fail (backend->priv != NULL);
+	g_return_if_fail (prop_name != NULL);
+	g_return_if_fail (*prop_name != '\0');
+	g_return_if_fail (prop_value != NULL);
+
+	priv = backend->priv;
+	g_mutex_lock (priv->clients_mutex);
+
+	for (clients = priv->clients; clients != NULL; clients = g_slist_next (clients))
+		e_data_book_report_backend_property_changed (E_DATA_BOOK (clients->data), prop_name, prop_value);
+
+	g_mutex_unlock (priv->clients_mutex);
+}
+
 /**
  * e_book_backend_respond_opened:
  * @backend: an #EBookBackend
@@ -1263,13 +1375,18 @@ e_book_backend_notify_opened (EBookBackend *backend, GError *error)
  *
  * This is a replacement for e_data_book_respond_open() for cases where
  * the finish of 'open' method call also finishes backend opening phase.
- * This function covers calling of both e_data_book_respond_open() and
- * e_book_backend_notify_opened() with the same @error.
+ * This function covers calling of both e_book_backend_notify_opened()
+ * and e_data_book_respond_open() with the same @error.
  *
  * See e_book_backend_open() for more details how the opening phase works.
+ *
+ * Since: 3.2
  **/
 void
-e_book_backend_respond_opened (EBookBackend *backend, EDataBook *book, guint32 opid, GError *error)
+e_book_backend_respond_opened (EBookBackend *backend,
+                               EDataBook *book,
+                               guint32 opid,
+                               GError *error)
 {
 	GError *copy = NULL;
 
@@ -1281,6 +1398,6 @@ e_book_backend_respond_opened (EBookBackend *backend, EDataBook *book, guint32 o
 	if (error)
 		copy = g_error_copy (error);
 
-	e_data_book_respond_open (book, opid, error);
 	e_book_backend_notify_opened (backend, copy);
+	e_data_book_respond_open (book, opid, error);
 }
