@@ -65,7 +65,7 @@ typedef enum {
 	OP_MODIFY_CONTACT,
 	OP_GET_BACKEND_PROPERTY,
 	OP_SET_BACKEND_PROPERTY,
-	OP_GET_BOOK_VIEW,
+	OP_GET_VIEW,
 	OP_CANCEL_OPERATION,
 	OP_CANCEL_ALL,
 	OP_CLOSE
@@ -89,7 +89,7 @@ typedef struct {
 		/* OP_ADD_CONTACT */
 		/* OP_MODIFY_CONTACT */
 		gchar *vcard;
-		/* OP_GET_BOOK_VIEW */
+		/* OP_GET_VIEW */
 		/* OP_GET_CONTACTS */
 		/* OP_GET_CONTACTS_UIDS */
 		gchar *query;
@@ -123,7 +123,9 @@ construct_bookview_path (void)
 }
 
 static void
-cancel_ops_cb (gpointer opid, gpointer cancellable, gpointer user_data)
+cancel_ops_cb (gpointer opid,
+               gpointer cancellable,
+               gpointer user_data)
 {
 	g_return_if_fail (cancellable != NULL);
 
@@ -131,7 +133,8 @@ cancel_ops_cb (gpointer opid, gpointer cancellable, gpointer user_data)
 }
 
 static void
-operation_thread (gpointer data, gpointer user_data)
+operation_thread (gpointer data,
+                  gpointer user_data)
 {
 	OperationData *op = data;
 	EBookBackend *backend;
@@ -182,7 +185,7 @@ operation_thread (gpointer data, gpointer user_data)
 		g_free (op->d.sbp.prop_name);
 		g_free (op->d.sbp.prop_value);
 		break;
-	case OP_GET_BOOK_VIEW:
+	case OP_GET_VIEW:
 		if (op->d.query) {
 			EBookBackendSExp *card_sexp;
 			EDataBookView *book_view;
@@ -254,7 +257,8 @@ operation_thread (gpointer data, gpointer user_data)
 }
 
 static OperationData *
-op_new (OperationID op, EDataBook *book)
+op_new (OperationID op,
+        EDataBook *book)
 {
 	OperationData *data;
 
@@ -272,7 +276,8 @@ op_new (OperationID op, EDataBook *book)
 }
 
 static void
-op_complete (EDataBook *book, guint32 opid)
+op_complete (EDataBook *book,
+             guint32 opid)
 {
 	g_return_if_fail (book != NULL);
 
@@ -320,7 +325,8 @@ e_data_book_status_to_string (EDataBookStatus status)
 		{ E_DATA_BOOK_STATUS_NO_SPACE,				N_("No space") },
 		{ E_DATA_BOOK_STATUS_INVALID_ARG,			N_("Invalid argument") },
 		/* Translators: The string for NOT_SUPPORTED error */
-		{ E_DATA_BOOK_STATUS_NOT_SUPPORTED,			N_("Not supported") }
+		{ E_DATA_BOOK_STATUS_NOT_SUPPORTED,			N_("Not supported") },
+		{ E_DATA_BOOK_STATUS_NOT_OPENED,			N_("Backend is not opened yet") }
 	};
 
 	for (i = 0; i < G_N_ELEMENTS (statuses); i++) {
@@ -361,7 +367,8 @@ e_data_book_error_quark (void)
 		{ E_DATA_BOOK_STATUS_INVALID_SERVER_VERSION,		ERR_PREFIX "InvalidServerVersion" },
 		{ E_DATA_BOOK_STATUS_NO_SPACE,				ERR_PREFIX "NoSpace" },
 		{ E_DATA_BOOK_STATUS_INVALID_ARG,			ERR_PREFIX "InvalidArg" },
-		{ E_DATA_BOOK_STATUS_NOT_SUPPORTED,			ERR_PREFIX "NotSupported" }
+		{ E_DATA_BOOK_STATUS_NOT_SUPPORTED,			ERR_PREFIX "NotSupported" },
+		{ E_DATA_BOOK_STATUS_NOT_OPENED,			ERR_PREFIX "NotOpened" }
 	};
 
 	#undef ERR_PREFIX
@@ -379,7 +386,8 @@ e_data_book_error_quark (void)
  * Since: 2.32
  **/
 GError *
-e_data_book_create_error (EDataBookStatus status, const gchar *custom_msg)
+e_data_book_create_error (EDataBookStatus status,
+                          const gchar *custom_msg)
 {
 	if (status == E_DATA_BOOK_STATUS_SUCCESS)
 		return NULL;
@@ -393,7 +401,9 @@ e_data_book_create_error (EDataBookStatus status, const gchar *custom_msg)
  * Since: 2.32
  **/
 GError *
-e_data_book_create_error_fmt (EDataBookStatus status, const gchar *custom_msg_fmt, ...)
+e_data_book_create_error_fmt (EDataBookStatus status,
+                              const gchar *custom_msg_fmt,
+                              ...)
 {
 	GError *error;
 	gchar *custom_msg;
@@ -413,7 +423,7 @@ e_data_book_create_error_fmt (EDataBookStatus status, const gchar *custom_msg_fm
 	return error;
 }
 
-ESource*
+ESource *
 e_data_book_get_source (EDataBook *book)
 {
 	g_return_val_if_fail (book != NULL, NULL);
@@ -422,7 +432,7 @@ e_data_book_get_source (EDataBook *book)
 	return book->priv->source;
 }
 
-EBookBackend*
+EBookBackend *
 e_data_book_get_backend (EDataBook *book)
 {
 	g_return_val_if_fail (book != NULL, NULL);
@@ -432,7 +442,9 @@ e_data_book_get_backend (EDataBook *book)
 }
 
 static void
-data_book_return_error (GDBusMethodInvocation *invocation, const GError *perror, const gchar *error_prefix)
+data_book_return_error (GDBusMethodInvocation *invocation,
+                        const GError *perror,
+                        const gchar *error_prefix)
 {
 	GError *error;
 
@@ -448,8 +460,14 @@ data_book_return_error (GDBusMethodInvocation *invocation, const GError *perror,
 	g_error_free (error);
 }
 
-/* takes a list of strings and converts it to a comma-separated string of values;
-   free returned pointer with g_free () */
+/**
+ * e_data_book_string_slist_to_comma_string:
+ *
+ * Takes a list of strings and converts it to a comma-separated string of
+ * values; free returned pointer with g_free()
+ *
+ * Since: 3.2
+ **/
 gchar *
 e_data_book_string_slist_to_comma_string (const GSList *strings)
 {
@@ -482,7 +500,10 @@ e_data_book_string_slist_to_comma_string (const GSList *strings)
 }
 
 static gboolean
-impl_Book_open (EGdbusBook *object, GDBusMethodInvocation *invocation, gboolean only_if_exists, EDataBook *book)
+impl_Book_open (EGdbusBook *object,
+                GDBusMethodInvocation *invocation,
+                gboolean only_if_exists,
+                EDataBook *book)
 {
 	OperationData *op;
 
@@ -496,7 +517,9 @@ impl_Book_open (EGdbusBook *object, GDBusMethodInvocation *invocation, gboolean
 }
 
 static gboolean
-impl_Book_remove (EGdbusBook *object, GDBusMethodInvocation *invocation, EDataBook *book)
+impl_Book_remove (EGdbusBook *object,
+                  GDBusMethodInvocation *invocation,
+                  EDataBook *book)
 {
 	OperationData *op;
 
@@ -509,7 +532,9 @@ impl_Book_remove (EGdbusBook *object, GDBusMethodInvocation *invocation, EDataBo
 }
 
 static gboolean
-impl_Book_refresh (EGdbusBook *object, GDBusMethodInvocation *invocation, EDataBook *book)
+impl_Book_refresh (EGdbusBook *object,
+                   GDBusMethodInvocation *invocation,
+                   EDataBook *book)
 {
 	OperationData *op;
 
@@ -522,7 +547,10 @@ impl_Book_refresh (EGdbusBook *object, GDBusMethodInvocation *invocation, EDataB
 }
 
 static gboolean
-impl_Book_get_contact (EGdbusBook *object, GDBusMethodInvocation *invocation, const gchar *in_uid, EDataBook *book)
+impl_Book_get_contact (EGdbusBook *object,
+                       GDBusMethodInvocation *invocation,
+                       const gchar *in_uid,
+                       EDataBook *book)
 {
 	OperationData *op;
 
@@ -546,7 +574,10 @@ impl_Book_get_contact (EGdbusBook *object, GDBusMethodInvocation *invocation, co
 }
 
 static gboolean
-impl_Book_get_contact_list (EGdbusBook *object, GDBusMethodInvocation *invocation, const gchar *in_query, EDataBook *book)
+impl_Book_get_contact_list (EGdbusBook *object,
+                            GDBusMethodInvocation *invocation,
+                            const gchar *in_query,
+                            EDataBook *book)
 {
 	OperationData *op;
 
@@ -568,7 +599,10 @@ impl_Book_get_contact_list (EGdbusBook *object, GDBusMethodInvocation *invocatio
 }
 
 static gboolean
-impl_Book_get_contact_list_uids (EGdbusBook *object, GDBusMethodInvocation *invocation, const gchar *in_query, EDataBook *book)
+impl_Book_get_contact_list_uids (EGdbusBook *object,
+                                 GDBusMethodInvocation *invocation,
+                                 const gchar *in_query,
+                                 EDataBook *book)
 {
 	OperationData *op;
 
@@ -590,7 +624,10 @@ impl_Book_get_contact_list_uids (EGdbusBook *object, GDBusMethodInvocation *invo
 }
 
 static gboolean
-impl_Book_add_contact (EGdbusBook *object, GDBusMethodInvocation *invocation, const gchar *in_vcard, EDataBook *book)
+impl_Book_add_contact (EGdbusBook *object,
+                       GDBusMethodInvocation *invocation,
+                       const gchar *in_vcard,
+                       EDataBook *book)
 {
 	OperationData *op;
 
@@ -612,7 +649,10 @@ impl_Book_add_contact (EGdbusBook *object, GDBusMethodInvocation *invocation, co
 }
 
 static gboolean
-impl_Book_modify_contact (EGdbusBook *object, GDBusMethodInvocation *invocation, const gchar *in_vcard, EDataBook *book)
+impl_Book_modify_contact (EGdbusBook *object,
+                          GDBusMethodInvocation *invocation,
+                          const gchar *in_vcard,
+                          EDataBook *book)
 {
 	OperationData *op;
 
@@ -634,7 +674,10 @@ impl_Book_modify_contact (EGdbusBook *object, GDBusMethodInvocation *invocation,
 }
 
 static gboolean
-impl_Book_remove_contacts (EGdbusBook *object, GDBusMethodInvocation *invocation, const gchar * const *in_uids, EDataBook *book)
+impl_Book_remove_contacts (EGdbusBook *object,
+                           GDBusMethodInvocation *invocation,
+                           const gchar * const *in_uids,
+                           EDataBook *book)
 {
 	OperationData *op;
 
@@ -652,7 +695,10 @@ impl_Book_remove_contacts (EGdbusBook *object, GDBusMethodInvocation *invocation
 }
 
 static gboolean
-impl_Book_get_backend_property (EGdbusBook *object, GDBusMethodInvocation *invocation, const gchar *in_prop_name, EDataBook *book)
+impl_Book_get_backend_property (EGdbusBook *object,
+                                GDBusMethodInvocation *invocation,
+                                const gchar *in_prop_name,
+                                EDataBook *book)
 {
 	OperationData *op;
 
@@ -666,7 +712,10 @@ impl_Book_get_backend_property (EGdbusBook *object, GDBusMethodInvocation *invoc
 }
 
 static gboolean
-impl_Book_set_backend_property (EGdbusBook *object, GDBusMethodInvocation *invocation, const gchar * const *in_prop_name_value, EDataBook *book)
+impl_Book_set_backend_property (EGdbusBook *object,
+                                GDBusMethodInvocation *invocation,
+                                const gchar * const *in_prop_name_value,
+                                EDataBook *book)
 {
 	OperationData *op;
 
@@ -680,7 +729,10 @@ impl_Book_set_backend_property (EGdbusBook *object, GDBusMethodInvocation *invoc
 }
 
 static gboolean
-impl_Book_get_view (EGdbusBook *object, GDBusMethodInvocation *invocation, const gchar *in_query, EDataBook *book)
+impl_Book_get_view (EGdbusBook *object,
+                    GDBusMethodInvocation *invocation,
+                    const gchar *in_query,
+                    EDataBook *book)
 {
 	OperationData *op;
 
@@ -695,7 +747,7 @@ impl_Book_get_view (EGdbusBook *object, GDBusMethodInvocation *invocation, const
 		return TRUE;
 	}
 
-	op = op_new (OP_GET_BOOK_VIEW, book);
+	op = op_new (OP_GET_VIEW, book);
 	op->d.query = g_strdup (in_query);
 
 	e_gdbus_book_complete_get_view (book->priv->gdbus_object, invocation, op->id);
@@ -705,7 +757,10 @@ impl_Book_get_view (EGdbusBook *object, GDBusMethodInvocation *invocation, const
 }
 
 static gboolean
-impl_Book_authenticate_user (EGdbusBook *object, GDBusMethodInvocation *invocation, const gchar * const *in_credentials, EDataBook *book)
+impl_Book_authenticate_user (EGdbusBook *object,
+                             GDBusMethodInvocation *invocation,
+                             const gchar * const *in_credentials,
+                             EDataBook *book)
 {
 	OperationData *op;
 
@@ -727,7 +782,10 @@ impl_Book_authenticate_user (EGdbusBook *object, GDBusMethodInvocation *invocati
 }
 
 static gboolean
-impl_Book_cancel_operation (EGdbusBook *object, GDBusMethodInvocation *invocation, guint in_opid, EDataBook *book)
+impl_Book_cancel_operation (EGdbusBook *object,
+                            GDBusMethodInvocation *invocation,
+                            guint in_opid,
+                            EDataBook *book)
 {
 	OperationData *op;
 
@@ -741,7 +799,9 @@ impl_Book_cancel_operation (EGdbusBook *object, GDBusMethodInvocation *invocatio
 }
 
 static gboolean
-impl_Book_cancel_all (EGdbusBook *object, GDBusMethodInvocation *invocation, EDataBook *book)
+impl_Book_cancel_all (EGdbusBook *object,
+                      GDBusMethodInvocation *invocation,
+                      EDataBook *book)
 {
 	OperationData *op;
 
@@ -754,7 +814,9 @@ impl_Book_cancel_all (EGdbusBook *object, GDBusMethodInvocation *invocation, EDa
 }
 
 static gboolean
-impl_Book_close (EGdbusBook *object, GDBusMethodInvocation *invocation, EDataBook *book)
+impl_Book_close (EGdbusBook *object,
+                 GDBusMethodInvocation *invocation,
+                 EDataBook *book)
 {
 	OperationData *op;
 
@@ -769,7 +831,9 @@ impl_Book_close (EGdbusBook *object, GDBusMethodInvocation *invocation, EDataBoo
 }
 
 void
-e_data_book_respond_open (EDataBook *book, guint opid, GError *error)
+e_data_book_respond_open (EDataBook *book,
+                          guint opid,
+                          GError *error)
 {
 	op_complete (book, opid);
 
@@ -783,7 +847,9 @@ e_data_book_respond_open (EDataBook *book, guint opid, GError *error)
 }
 
 void
-e_data_book_respond_remove (EDataBook *book, guint opid, GError *error)
+e_data_book_respond_remove (EDataBook *book,
+                            guint opid,
+                            GError *error)
 {
 	op_complete (book, opid);
 
@@ -808,7 +874,9 @@ e_data_book_respond_remove (EDataBook *book, guint opid, GError *error)
  * Since: 3.2
  */
 void
-e_data_book_respond_refresh (EDataBook *book, guint32 opid, GError *error)
+e_data_book_respond_refresh (EDataBook *book,
+                             guint32 opid,
+                             GError *error)
 {
 	op_complete (book, opid);
 
@@ -821,8 +889,18 @@ e_data_book_respond_refresh (EDataBook *book, guint32 opid, GError *error)
 		g_error_free (error);
 }
 
+/**
+ * e_data_book_respond_get_backend_property:
+ *
+ * FIXME: Document me.
+ *
+ * Since: 3.2
+ **/
 void
-e_data_book_respond_get_backend_property (EDataBook *book, guint32 opid, GError *error, const gchar *prop_value)
+e_data_book_respond_get_backend_property (EDataBook *book,
+                                          guint32 opid,
+                                          GError *error,
+                                          const gchar *prop_value)
 {
 	gchar *gdbus_prop_value = NULL;
 
@@ -839,8 +917,17 @@ e_data_book_respond_get_backend_property (EDataBook *book, guint32 opid, GError
 	g_free (gdbus_prop_value);
 }
 
+/**
+ * e_data_book_respond_set_backend_property:
+ *
+ * FIXME: Document me.
+ *
+ * Since: 3.2
+ **/
 void
-e_data_book_respond_set_backend_property (EDataBook *book, guint32 opid, GError *error)
+e_data_book_respond_set_backend_property (EDataBook *book,
+                                          guint32 opid,
+                                          GError *error)
 {
 	op_complete (book, opid);
 
@@ -854,7 +941,10 @@ e_data_book_respond_set_backend_property (EDataBook *book, guint32 opid, GError
 }
 
 void
-e_data_book_respond_get_contact (EDataBook *book, guint32 opid, GError *error, const gchar *vcard)
+e_data_book_respond_get_contact (EDataBook *book,
+                                 guint32 opid,
+                                 GError *error,
+                                 const gchar *vcard)
 {
 	gchar *gdbus_vcard = NULL;
 
@@ -872,7 +962,10 @@ e_data_book_respond_get_contact (EDataBook *book, guint32 opid, GError *error, c
 }
 
 void
-e_data_book_respond_get_contact_list (EDataBook *book, guint32 opid, GError *error, const GSList *cards)
+e_data_book_respond_get_contact_list (EDataBook *book,
+                                      guint32 opid,
+                                      GError *error,
+                                      const GSList *cards)
 {
 	if (error) {
 		/* Translators: This is prefix to a detailed error message */
@@ -895,8 +988,18 @@ e_data_book_respond_get_contact_list (EDataBook *book, guint32 opid, GError *err
 	}
 }
 
+/**
+ * e_data_book_respond_get_contact_list_uids:
+ *
+ * FIXME: Document me.
+ *
+ * Since: 3.2
+ **/
 void
-e_data_book_respond_get_contact_list_uids (EDataBook *book, guint32 opid, GError *error, const GSList *uids)
+e_data_book_respond_get_contact_list_uids (EDataBook *book,
+                                           guint32 opid,
+                                           GError *error,
+                                           const GSList *uids)
 {
 	if (error) {
 		/* Translators: This is prefix to a detailed error message */
@@ -920,7 +1023,10 @@ e_data_book_respond_get_contact_list_uids (EDataBook *book, guint32 opid, GError
 }
 
 void
-e_data_book_respond_create (EDataBook *book, guint32 opid, GError *error, const EContact *contact)
+e_data_book_respond_create (EDataBook *book,
+                            guint32 opid,
+                            GError *error,
+                            const EContact *contact)
 {
 	gchar *gdbus_uid = NULL;
 
@@ -941,7 +1047,10 @@ e_data_book_respond_create (EDataBook *book, guint32 opid, GError *error, const
 }
 
 void
-e_data_book_respond_modify (EDataBook *book, guint32 opid, GError *error, const EContact *contact)
+e_data_book_respond_modify (EDataBook *book,
+                            guint32 opid,
+                            GError *error,
+                            const EContact *contact)
 {
 	op_complete (book, opid);
 
@@ -959,7 +1068,10 @@ e_data_book_respond_modify (EDataBook *book, guint32 opid, GError *error, const
 }
 
 void
-e_data_book_respond_remove_contacts (EDataBook *book, guint32 opid, GError *error, const GSList *ids)
+e_data_book_respond_remove_contacts (EDataBook *book,
+                                     guint32 opid,
+                                     GError *error,
+                                     const GSList *ids)
 {
 	op_complete (book, opid);
 
@@ -981,8 +1093,16 @@ e_data_book_respond_remove_contacts (EDataBook *book, guint32 opid, GError *erro
 
 }
 
+/**
+ * e_data_book_report_error:
+ *
+ * FIXME: Document me.
+ *
+ * Since: 3.2
+ **/
 void
-e_data_book_report_error (EDataBook *book, const gchar *message)
+e_data_book_report_error (EDataBook *book,
+                          const gchar *message)
 {
 	g_return_if_fail (book != NULL);
 	g_return_if_fail (message != NULL);
@@ -990,16 +1110,32 @@ e_data_book_report_error (EDataBook *book, const gchar *message)
 	e_gdbus_book_emit_backend_error (book->priv->gdbus_object, message);
 }
 
+/**
+ * e_data_book_report_readonly:
+ *
+ * FIXME: Document me.
+ *
+ * Since: 3.2
+ **/
 void
-e_data_book_report_readonly (EDataBook *book, gboolean readonly)
+e_data_book_report_readonly (EDataBook *book,
+                             gboolean readonly)
 {
 	g_return_if_fail (book != NULL);
 
 	e_gdbus_book_emit_readonly (book->priv->gdbus_object, readonly);
 }
 
+/**
+ * e_data_book_report_online:
+ *
+ * FIXME: Document me.
+ *
+ * Since: 3.2
+ **/
 void
-e_data_book_report_online (EDataBook *book, gboolean is_online)
+e_data_book_report_online (EDataBook *book,
+                           gboolean is_online)
 {
 	g_return_if_fail (book != NULL);
 
@@ -1007,10 +1143,11 @@ e_data_book_report_online (EDataBook *book, gboolean is_online)
 }
 
 /* credentilas contains extra information for a source for which authentication is requested.
-   This parameter can be NULL to indicate "for this book".
+ * This parameter can be NULL to indicate "for this book".
 */
 void
-e_data_book_report_auth_required (EDataBook *book, const ECredentials *credentials)
+e_data_book_report_auth_required (EDataBook *book,
+                                  const ECredentials *credentials)
 {
 	gchar *empty_strv[2];
 	gchar **strv = NULL;
@@ -1028,13 +1165,19 @@ e_data_book_report_auth_required (EDataBook *book, const ECredentials *credentia
 	g_strfreev (strv);
 }
 
-/* Reports to associated client that opening phase of the book is finished.
-   error being NULL means successfully, otherwise reports an error which happened
-   during opening phase. By opening phase is meant a process including successfull
-   authentication to the server/storage.
-*/
+/**
+ * e_data_book_report_opened:
+ *
+ * Reports to associated client that opening phase of the book is finished.
+ * error being NULL means successfully, otherwise reports an error which
+ * happened during opening phase. By opening phase is meant a process
+ * including successfull authentication to the server/storage.
+ *
+ * Since: 3.2
+ **/
 void
-e_data_book_report_opened (EDataBook *book, const GError *error)
+e_data_book_report_opened (EDataBook *book,
+                           const GError *error)
 {
 	gchar **strv_error;
 
@@ -1045,6 +1188,35 @@ e_data_book_report_opened (EDataBook *book, const GError *error)
 	g_strfreev (strv_error);
 }
 
+/**
+ * e_data_book_report_backend_property_changed:
+ *
+ * FIXME: Document me.
+ *
+ * Since: 3.2
+ **/
+void
+e_data_book_report_backend_property_changed (EDataBook *book,
+                                             const gchar *prop_name,
+                                             const gchar *prop_value)
+{
+	gchar **strv;
+
+	/* Notifies client about certain property value change */
+
+	g_return_if_fail (book != NULL);
+	g_return_if_fail (prop_name != NULL);
+	g_return_if_fail (*prop_name != '\0');
+	g_return_if_fail (prop_value != NULL);
+
+	strv = e_gdbus_templates_encode_two_strings (prop_name, prop_value);
+	g_return_if_fail (strv != NULL);
+
+	e_gdbus_book_emit_backend_property_changed (book->priv->gdbus_object, (const gchar * const *) strv);
+
+	g_strfreev (strv);
+}
+
 /**
  * e_data_book_register_gdbus_object:
  *
@@ -1053,7 +1225,10 @@ e_data_book_report_opened (EDataBook *book, const GError *error)
  * Since: 2.32
  **/
 guint
-e_data_book_register_gdbus_object (EDataBook *book, GDBusConnection *connection, const gchar *object_path, GError **error)
+e_data_book_register_gdbus_object (EDataBook *book,
+                                   GDBusConnection *connection,
+                                   const gchar *object_path,
+                                   GError **error)
 {
 	g_return_val_if_fail (book != NULL, 0);
 	g_return_val_if_fail (E_IS_DATA_BOOK (book), 0);
@@ -1148,7 +1323,8 @@ e_data_book_class_init (EDataBookClass *klass)
 }
 
 EDataBook *
-e_data_book_new (EBookBackend *backend, ESource *source)
+e_data_book_new (EBookBackend *backend,
+                 ESource *source)
 {
 	EDataBook *book;
 
