@@ -52,9 +52,7 @@
 
 #include "e-gdbus-cal-factory.h"
 
-#ifdef HAVE_ICAL_UNKNOWN_TOKEN_HANDLING
 #include <libical/ical.h>
-#endif
 
 #ifdef G_OS_WIN32
 #include <windows.h>
@@ -272,7 +270,8 @@ remove_dead_calendar_cb (gpointer path,
 }
 
 static void
-calendar_freed_cb (EDataCalFactory *factory, GObject *dead)
+calendar_freed_cb (EDataCalFactory *factory,
+                   GObject *dead)
 {
 	EDataCalFactoryPrivate *priv = factory->priv;
 	GHashTableIter iter;
@@ -310,7 +309,8 @@ calendar_freed_cb (EDataCalFactory *factory, GObject *dead)
 }
 
 static void
-last_client_gone_cb (ECalBackend *backend, EDataCalFactory *factory)
+last_client_gone_cb (ECalBackend *backend,
+                     EDataCalFactory *factory)
 {
 	EDataCalFactoryPrivate *priv = factory->priv;
 
@@ -329,7 +329,9 @@ struct find_backend_data {
 };
 
 static void
-find_backend_cb (gpointer key, gpointer value, gpointer data)
+find_backend_cb (gpointer key,
+                 gpointer value,
+                 gpointer data)
 {
 	struct find_backend_data *fbd = data;
 
@@ -539,9 +541,9 @@ impl_CalFactory_get_cal (EGdbusCalFactory *object,
 
 cleanup:
 	/* The reason why the lock is held for such a long time is that there is
-	   a subtle race where e_cal_backend_add_client () can be called just
-	   before e_cal_backend_finalize () is called from the
-	   backend_last_client_gone_cb (), for details see bug 506457. */
+	 * a subtle race where e_cal_backend_add_client () can be called just
+	 * before e_cal_backend_finalize () is called from the
+	 * backend_last_client_gone_cb (), for details see bug 506457. */
 	g_mutex_unlock (priv->backends_mutex);
 
 cleanup2:
@@ -577,7 +579,9 @@ remove_data_cal_cb (gpointer data_cl,
 }
 
 static void
-unref_backend_cb (gpointer key, gpointer value, gpointer user_data)
+unref_backend_cb (gpointer key,
+                  gpointer value,
+                  gpointer user_data)
 {
 	ECalBackend *backend = value;
 
@@ -705,6 +709,8 @@ e_data_cal_factory_register_gdbus_object (EDataCalFactory *factory,
  * @is_online: Online mode to set.
  *
  * Sets the online mode for all backends created by the given factory.
+ *
+ * Since: 3.2
  */
 void
 e_data_cal_factory_set_backend_online (EDataCalFactory *factory,
@@ -854,7 +860,9 @@ e_data_cal_factory_get_n_backends (EDataCalFactory *factory)
 
 /* Frees a uri/backend pair from the backends hash table */
 static void
-dump_backend (gpointer key, gpointer value, gpointer data)
+dump_backend (gpointer key,
+              gpointer value,
+              gpointer data)
 {
 	gchar *uri;
 	ECalBackend *backend;
@@ -989,13 +997,16 @@ static GOptionEntry entries[] = {
 };
 
 gint
-main (gint argc, gchar **argv)
+main (gint argc,
+      gchar **argv)
 {
 	EOfflineListener *eol;
 	GOptionContext *context;
 	EDataCalFactory *factory;
 	guint owner_id;
 	GError *error = NULL;
+	icalarray *builtin_timezones;
+	gint ii;
 
 #ifdef G_OS_WIN32
 	/* Reduce risks */
@@ -1014,7 +1025,7 @@ main (gint argc, gchar **argv)
 
 		p_SetProcessDEPPolicy = GetProcAddress (GetModuleHandle ("kernel32.dll"), "SetProcessDEPPolicy");
 		if (p_SetProcessDEPPolicy)
-			(*p_SetProcessDEPPolicy) (PROCESS_DEP_ENABLE|PROCESS_DEP_DISABLE_ATL_THUNK_EMULATION);
+			(*p_SetProcessDEPPolicy) (PROCESS_DEP_ENABLE | PROCESS_DEP_DISABLE_ATL_THUNK_EMULATION);
 	}
 #endif
 #endif
@@ -1046,6 +1057,29 @@ main (gint argc, gchar **argv)
 	ical_set_unknown_token_handling_setting (ICAL_DISCARD_TOKEN);
 #endif
 
+	/* XXX Pre-load all built-in timezones in libical.
+	 *
+	 *     Built-in time zones in libical 0.43 are loaded on demand,
+	 *     but not in a thread-safe manner, resulting in a race when
+	 *     multiple threads call icaltimezone_load_builtin_timezone()
+	 *     on the same time zone.  Until built-in time zone loading
+	 *     in libical is made thread-safe, work around the issue by
+	 *     loading all built-in time zones now, so libical's internal
+	 *     time zone array will be fully populated before any threads
+	 *     are spawned.
+	 */
+	builtin_timezones = icaltimezone_get_builtin_timezones ();
+	for (ii = 0; ii < builtin_timezones->num_elements; ii++) {
+		icaltimezone *zone;
+
+		zone = icalarray_element_at (builtin_timezones, ii);
+
+		/* We don't care about the component right now,
+		 * we just need some function that will trigger
+		 * icaltimezone_load_builtin_timezone(). */
+		icaltimezone_get_component (zone);
+	}
+
 	factory = g_object_new (E_TYPE_DATA_CAL_FACTORY, NULL);
 
 	loop = g_main_loop_new (NULL, FALSE);
@@ -1070,7 +1104,11 @@ main (gint argc, gchar **argv)
 	e_data_cal_migrate_basedir ();
 
 #ifdef G_OS_UNIX
-#if GLIB_CHECK_VERSION(2,29,5)
+#if GLIB_CHECK_VERSION(2,29,19)
+	g_unix_signal_add_full (
+		G_PRIORITY_DEFAULT, SIGTERM,
+		handle_term_signal, NULL, NULL);
+#elif GLIB_CHECK_VERSION(2,29,5)
 	g_unix_signal_add_watch_full (
 		SIGTERM, G_PRIORITY_DEFAULT,
 		handle_term_signal, NULL, NULL);
