@@ -104,8 +104,8 @@ maildir_folder_get_filename (CamelFolder *folder,
 	mdi = (CamelMaildirMessageInfo *) info;
 
 	/* If filename is NULL, it means folder_summary_check is not yet executed.
-	   Try to find the file in the folder and use it, otherwise construct its
-	   name based on actual flags.
+	 * Try to find the file in the folder and use it, otherwise construct its
+	 * name based on actual flags.
 	*/
 	if (!camel_maildir_info_filename (mdi)) {
 		const gchar *uid = camel_message_info_uid (info);
@@ -183,7 +183,7 @@ maildir_folder_append_message_sync (CamelFolder *folder,
 	/* write it out to tmp, use the uid we got from the summary */
 	name = g_strdup_printf ("%s/tmp/%s", lf->folder_path, camel_message_info_uid(mi));
 	output_stream = camel_stream_fs_new_with_name (
-		name, O_WRONLY|O_CREAT, 0600, error);
+		name, O_WRONLY | O_CREAT, 0600, error);
 	if (output_stream == NULL)
 		goto fail_write;
 
@@ -224,7 +224,7 @@ maildir_folder_append_message_sync (CamelFolder *folder,
 		name);
 
 	if (output_stream) {
-		g_object_unref (CAMEL_OBJECT (output_stream));
+		g_object_unref (output_stream);
 		unlink (name);
 	}
 
@@ -309,7 +309,8 @@ maildir_folder_transfer_messages_to_sync (CamelFolder *source,
 {
 	gboolean fallback = FALSE;
 
-	if (delete_originals && CAMEL_IS_MAILDIR_FOLDER (source) && CAMEL_IS_MAILDIR_FOLDER (dest)) {
+	if (delete_originals && CAMEL_IS_MAILDIR_FOLDER (source) && CAMEL_IS_MAILDIR_FOLDER (dest)
+	    && camel_folder_get_parent_store (source) == camel_folder_get_parent_store (dest)) {
 		gint i;
 		CamelLocalFolder *lf = (CamelLocalFolder *) source;
 		CamelLocalFolder *df = (CamelLocalFolder *) dest;
@@ -322,7 +323,7 @@ maildir_folder_transfer_messages_to_sync (CamelFolder *source,
 
 		for (i = 0; i < uids->len; i++) {
 			gchar *uid = (gchar *) uids->pdata[i];
-			gchar *s_filename, *d_filename, *tmp;
+			gchar *s_filename, *d_filename, *new_filename;
 			CamelMaildirMessageInfo *mdi;
 			CamelMessageInfo *info;
 
@@ -334,10 +335,9 @@ maildir_folder_transfer_messages_to_sync (CamelFolder *source,
 			}
 
 			mdi = (CamelMaildirMessageInfo *) info;
-			tmp = camel_maildir_summary_info_to_name (mdi);
+			new_filename = camel_maildir_summary_info_to_name (mdi);
 
-			d_filename = g_strdup_printf ("%s/cur/%s", df->folder_path, tmp);
-			g_free (tmp);
+			d_filename = g_strdup_printf ("%s/cur/%s", df->folder_path, new_filename);
 			s_filename = g_strdup_printf("%s/cur/%s", lf->folder_path, camel_maildir_info_filename (mdi));
 
 			if (g_rename (s_filename, d_filename) != 0) {
@@ -354,15 +354,47 @@ maildir_folder_transfer_messages_to_sync (CamelFolder *source,
 					break;
 				}
 			} else {
+				CamelMessageInfo *clone;
+				CamelMaildirMessageInfo *mclone;
+
+				clone = camel_message_info_clone (info);
+				clone->summary = dest->summary;
+
+				mclone = (CamelMaildirMessageInfo *) clone;
+				/* preserve also UID, as it matches the file name */
+				mclone->info.info.uid = camel_pstring_strdup (camel_message_info_uid (info));
+				camel_maildir_info_set_filename (clone, g_strdup (new_filename));
+				/* unset deleted flag when transferring from trash folder */
+				if ((source->folder_flags & CAMEL_FOLDER_IS_TRASH) != 0)
+					camel_message_info_set_flags (info, CAMEL_MESSAGE_DELETED, 0);
+				/* unset junk flag when transferring from junk folder */
+				if ((source->folder_flags & CAMEL_FOLDER_IS_JUNK) != 0)
+					camel_message_info_set_flags (info, CAMEL_MESSAGE_JUNK, 0);
+				camel_folder_summary_add (dest->summary, clone);
+
+				camel_folder_change_info_add_uid (df->changes, camel_message_info_uid (clone));
+
 				camel_folder_set_message_flags (
 					source, uid, CAMEL_MESSAGE_DELETED |
 					CAMEL_MESSAGE_SEEN, ~0);
+				camel_folder_change_info_remove_uid (lf->changes, camel_message_info_uid (info));
 				camel_folder_summary_remove (source->summary, info);
 			}
 
 			camel_message_info_free (info);
 			g_free (s_filename);
 			g_free (d_filename);
+			g_free (new_filename);
+		}
+
+		if (lf && camel_folder_change_info_changed (lf->changes)) {
+			camel_folder_changed (source, lf->changes);
+			camel_folder_change_info_clear (lf->changes);
+		}
+
+		if (df && camel_folder_change_info_changed (df->changes)) {
+			camel_folder_changed (dest, df->changes);
+			camel_folder_change_info_clear (df->changes);
 		}
 
 		camel_folder_thaw (source);
@@ -426,6 +458,9 @@ camel_maildir_folder_new (CamelStore *parent_store,
                           GError **error)
 {
 	CamelFolder *folder;
+	CamelService *service;
+	CamelSettings *settings;
+	gboolean filter_inbox;
 	gchar *basename;
 
 	d(printf("Creating maildir folder: %s\n", full_name));
@@ -440,8 +475,13 @@ camel_maildir_folder_new (CamelStore *parent_store,
 		"display-name", basename, "full-name", full_name,
 		"parent-store", parent_store, NULL);
 
-	if (parent_store->flags & CAMEL_STORE_FILTER_INBOX
-	    && strcmp(full_name, ".") == 0)
+	service = CAMEL_SERVICE (parent_store);
+	settings = camel_service_get_settings (service);
+
+	filter_inbox = camel_store_settings_get_filter_inbox (
+		CAMEL_STORE_SETTINGS (settings));
+
+	if (filter_inbox && strcmp (full_name, ".") == 0)
 		folder->folder_flags |= CAMEL_FOLDER_FILTER_RECENT;
 
 	folder = (CamelFolder *) camel_local_folder_construct (
