@@ -718,7 +718,7 @@ e_source_set_color_spec (ESource *source,
  * Returns the #ESourceGroup to which @source belongs, or %NULL if it
  * does not belong to a group.
  *
- * Returns: (transfer none): the group to which the source belongs
+ * Returns: (transfer none): the #ESourceGroup to which the source belongs
  **/
 ESourceGroup *
 e_source_peek_group (ESource *source)
@@ -1151,9 +1151,16 @@ e_source_set_property (ESource *source,
                        const gchar *property_name,
                        const gchar *property_value)
 {
+	const gchar *old_value;
+
 	g_return_if_fail (E_IS_SOURCE (source));
 	g_return_if_fail (property_name != NULL);
 
+	old_value = g_hash_table_lookup (source->priv->properties, property_name);
+
+	if (g_strcmp0 (old_value, property_value) == 0)
+		return;
+
 	if (property_value != NULL)
 		g_hash_table_replace (
 			source->priv->properties,
